/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "domstubs.idl"

/**
 * The nsIDOMStyleSheetList interface is a datatype for a style sheet
 * list in the Document Object Model.
 *
 * For more information on this interface please see
 * http://www.w3.org/TR/DOM-Level-2-Style
 */

[uuid(0e424250-ac2a-4fe2-bccd-a45824af090e)]
interface nsIDOMStyleSheetList : nsISupports
{
  readonly attribute unsigned long    length;
  [binaryname(SlowItem)]
  nsIDOMStyleSheet         item(in unsigned long index);
};
